@@ -24,8 +24,8 @@ public:
     ~DlgSettingsWidget();
 
 public slots:
-    virtual void save();
-    virtual void load();
+    virtual void save() override;
+    virtual void load() override;
 
 private:
     Ui::DlgMetalink ui;
